/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb;

import edu.rpi.scheduler.schedb.spec.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Collection;
import java.util.LinkedList;

/**
 * An Implementation of {@code Course} and {@code AbstractCourse} 
 * that supports a list of sections in addition to the functionality
 * in {@code AbstractCourse}.
 */
public class  DefaultCourse extends AbstractCourse {
    private final List<Section> sections = new ArrayList<Section>();

    public DefaultCourse(String coursename, CourseID coursenum,
                         GradeType gradeType, DoubleRange credits, Notes notes) {
        super(coursename, coursenum, gradeType, credits, notes);
    }

    /**
     * Add a section to this course
     * @param section Section object to add
     */
    public void addSection(Section section) {
        sections.add(section);
    }

    public List<Section> getSections() {
        return sections;
    }

	public List<Section> getSectionsInPoT(String PoT) {
		List<Section> out = new LinkedList<Section>();
		for(Section s: sections){
			if(s.getPartOfTerm().equals("Full Semester")){
				if(Year.getInstance().getTerm(s.getTerm()).getPartOfTerms().contains(PoT)){
					out.add(s);
				}
			}else if(s.getPartOfTerm().equals(PoT)){
				out.add(s);
			}
		 }
		return out;
	}

	public Section getSectionWithSectionIdString(String idstr) {
        for (Section section : sections) {
            if (section.getID().getUniqueStringForm().equals(idstr)) {
                return section;
            }
        }
        return null;
    }

	/**
	 * This gets a list of strings containing all the part of term identifiers for PoTs during which
	 * this course is offered
	 * @return List of String with one PoT identifier per string with no repeats
	 */
	public List<String> getPartOfTermsOffered(){
		List<String> out = new LinkedList<String>();
		for(Section s: sections){
			
			if(s.getPartOfTerm().equals("Full Semester")){
				for(int i=0; i<Year.getInstance().getTerm(s.getTerm()).getNumberOfPartOfTerms(); i++){
					if(!out.contains(s.getPartOfTerm())){
						out.add(Year.getInstance().getTerm(s.getTerm()).getPartOfTerm(i).getIdentifier());
					}
				}
			}else{
				if(!out.contains(s.getPartOfTerm())){
					out.add(s.getPartOfTerm());
				}
			}
		}

		return out;
	}
}
