/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb;

import edu.rpi.scheduler.schedb.spec.SectionNumber;
/**
 * Object to store a section number as an int
 * Note that there is also a {@code StringSectionNumber} class that
 * stores Section Numbers as Strings. 
 */
public class IntSectionNumber implements SectionNumber {
    private final int number;

    /** 
     * Constructor
     * @param number int of the section number
     */
    public IntSectionNumber(int number) {
        this.number = number;
    }

    /**
     * Return the section number as an int
     * @return int equal to the section number
     */
    public int getNumber() { return number; }

    /**
     * Compares this section to another IntSectionNumber object
     * @throws IllegalArgumentException if passed object is not of type
     *  IntSectionNumber
     *  @param o SectionNumber object to compare with
     */
    public int compareTo(SectionNumber o) {
        if (!(o instanceof IntSectionNumber)) {
            throw new IllegalArgumentException("can't compare "
                    + getClass().getName() + " to " + o.getClass().getName());
        }
        IntSectionNumber s = (IntSectionNumber) o;

        return getNumber() - s.getNumber();
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof IntSectionNumber)) return false;
        IntSectionNumber ssn = (IntSectionNumber) obj;
        return getNumber() == ssn.getNumber();
    }

    public int hashCode() {
        return getNumber();
    }

 
    public String toString() {
        return Integer.toString(getNumber());
    }
}
