/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb;

import edu.rpi.scheduler.schedb.spec.CourseID;

/**
 * Class to store Course ID information as a string.
 */
public class StringCourseID implements CourseID {
    /**
     * Number representing the course ID
     */
    private final String number;

    /**
     * Course ID for a course
     * @param number the course ID number
     */
    public StringCourseID(String number) {
        this.number = number;
    }

    public String getNumber() { return number; }

    /**
     * Performs the JAVA comparison between two course IDs (numbers)
     * @param o the Course ID to compare this one against
     * @return integer with the same output as javalang.Compareable
     */
    public int compareTo(CourseID o) {
        if (!(o instanceof StringCourseID)) {
            throw new IllegalArgumentException("cannot compare "
                    + getClass().getName() + " to " + getClass().getName());
        }
        StringCourseID cid = (StringCourseID) o;

        return getNumber().compareTo(cid.getNumber());
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof StringCourseID)) return false;
        StringCourseID cid = (StringCourseID) obj;

        return getNumber().equals(cid.getNumber());
    }

    public int hashCode() {
        return getNumber().hashCode();
    }

    public String toString() {
        return getNumber();
    }

    public String getUniqueString() {
        return getNumber();
    }
}
