/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb;

import edu.rpi.scheduler.schedb.spec.SectionID;

/**
 * Class for storing a SectionID as a string.
 */
public class StringSectionID implements SectionID {
    private final String secid;

    /**
     * Constructor for a StringSectionID with a given section ID string
     * @param secid String containing the section ID
     */
    public StringSectionID(String secid) {
        this.secid = secid;
    }

    /**
     * Compares this StringSectionID with another SectionID object
     * @throws IllegalArgumentException  if the obect we are compareing
     * isnt of type StringSectionID
     * @param o SectionID to compare against (really has to be of type
     * StringSectionID to not generate an error) 
     */
    public int compareTo(SectionID o) {
        if (!(o instanceof StringSectionID)) {
            throw new IllegalArgumentException("cannot compare "
                    + getClass().getName() + " to " + o.getClass().getName());
        }
        StringSectionID id = (StringSectionID) o;

        return getUniqueStringForm().compareTo(id.getUniqueStringForm());
    }

    
    public boolean equals(Object obj) {
        if (!(obj instanceof StringSectionID)) return false;
        StringSectionID sid = (StringSectionID) obj;

        return getUniqueStringForm().equals(sid.getUniqueStringForm());
    }

    public int hashCode() {
        return getUniqueStringForm().hashCode();
    }

    public String toString() {
        return getUniqueStringForm();
    }

    public String getUniqueStringForm() {
        return secid;
    }
}
