/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb.spec;

import java.util.Collection;

/**
 * Departments essentially hold a map of course objects vs course IDs for 
 * the courses within that department. 
 */
public interface Department extends Comparable<Department> {
    /** 
     * @return String with the Abbreviation of the department
     */
	String getAbbrev();
	/** 
     * @return String with the Name of the department
     */
    String getName();
    /**
     * Return the course in the department with the given CourseID
     * @param courseid CourseID object to search for
     * @return Course object with matching CourseID in the department
     */
    Course getCourse(CourseID courseid);
    /** 
     * @return A collection of courses that are in this department
     */
    Collection<Course> getCourses();

    /**
     * Checks if a course exists in the department
     * @param course the Course object we are looking for
     * @return true if the course exists in the department, false otherwise
     */
    boolean containsCourse(Course course);

    /**
     * Returns the course object with the given courseID in string format
     * @param courseIdString CourseID as a String
     * @return Course Object with matching courseID number
     */
    Course getCourseWithCourseIdString(String courseIdString);
}
