/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb.spec;

import edu.rpi.scheduler.schedb.UniqueSection;
import edu.rpi.scheduler.schedb.WeekMask;
import edu.rpi.scheduler.schedb.YearMask;

import java.util.Collection;
import java.util.List;
/**
 * Interface for a schedule.  I *believe* a schedule is actually the
 * student's schedule as opposed to a {@code SchedulerData}which is the 
 * actual complete "master" schedule.
 */
public interface Schedule {
	/**
	 * Add a section to this schedule
	 * @param section UniqueSection to be added to this schedule
	 */
    void addSection(UniqueSection section);

    /**
     * Determine if you can add a section to this schedule
     * @param section UniqueSection to test
     * @return True if section can be added 
     */
    boolean canAdd(UniqueSection section);

	/**
	 * Returns the SchedulerDataPlugin for this Schedule
	 * @return SchedulerDataPlugin for this Schedule
	 */
	public SchedulerDataPlugin getSchedulerPlugin();
	/**
     * Determine if you can add something to this schedule
     * the "something" occupies the WeekMask 
     * 
     * TODO Verify this is indeed how this works
     * 
     #* @param section UniqueSection to test
     * @return True if section can be added 
     */
    boolean canAdd(YearMask<?> mask);

    /**
     * Get the WeekMask showing the times this schedule occupies
     * @return WeekMask a time mask showing when the schedule is busy
     */
    YearMask<?> getTimeMask();

    /**
     * Returns a collection of UniqueSections that make up this schedule
     * @return a collection of UniqueSections that make up this schedule
     */
    Collection<UniqueSection> getSections();

	/**
	 * Returns a collection of Unique sections that make up this schedule for a given term and part of Term
	 * @param Term the term identifier for this term
	 * @param PoT the part of term for this term
	 * @return a collection of UniqueSections that make up this part of the schedule
	 */
    Collection<UniqueSection> getSections(String Term, String PoT);

	//TODO Determine what this function does
    YearMask<?> getClassMask();

    /**
     * Gets the number of days of classes in this schedule
     * @return int the number of days that have a class on them
     */
    int getDaysOfClass();
    
    //TODO Determine what this function does
    int[] getTimeSums();

    //TODO Determine what this function does
    List<List<TimePeriod>> getBetweens(String Term, String PartOfTerm);
}
