/*
 *  Copyright (c) 2004, The University Scheduler Project
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of the University Scheduler Project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

package edu.rpi.scheduler.schedb.spec;

import java.util.Collection;
import java.util.Date;

/**
 * Represents a set of schedule data.  
 * I *believe* this object represents a complete "master" schedule,
 * as opposed to a {@code Schedule} which is a single user's schedule.
 */
public interface SchedulerData {
	/**
	 * Return the data context for this schedule data 
	 * @return the data context for this schedule data 
	 */
    DataContext getDataContext();

    /**
     * Return the DataSetId for this schedule data
     * @return the DataSetId for this schedule data
     */
    String getDataSetId();
    
    /**
     * Return a Date object for the tmie this schedule was last modified
     * @return a Date object for the tmie this schedule was last modified
     */
    Date getLastModified();

    /**
     * Returns a collection of Departments that make up this schedule
     * @return Collection<Department> the departments that make up this schedule
     */
    Collection<Department> getDepartments();
    /**
     * Returns a collection of Courses that make up this schedule
     * @return a collection of Courses that make up this schedule
     */
    Collection<Course> getCourses();
    /**
     * Returns a collection of Sections that make up this schedule
     * @return a collection of Sections that make up this schedule
     */
    Collection<Section> getSections();

    /**
     * Returns the department object that matches the abbreviation given
     * to this function.  This function only looks in the departments
     * contained in this schedule data object. 
     * @param abbrev String containing the department abreviation to look up
     * @return Department object matcthing the abbreviation or Null if none found
     */
    Department getDepartment(String abbrev);
}
