package edu.rpi.scheduler.schedb.spec;

import java.util.List;
import java.util.LinkedList;

/**
 *A PartOfTerm is a part of a larger term (think semester).
 *
 * At WPI we generally refer to our PartOfTerms as Terms.
 *
 * User: Peter
 * Date: Sep 19, 2007
 * Time: 4:09:38 PM
 */
public class Term {
    //public Collection<SubTerm> getSubTerms();
    private final String identifier;
    private final String displayName;
	private List<PartOfTerm> PartsOfTerm = new LinkedList<PartOfTerm>();

	public Term(String identifierAndName) {
        this(identifierAndName, identifierAndName);
    }
    public Term(String identifier, String displayName) {
        this.identifier = identifier;
        this.displayName = displayName;
    }
	public Term(String identifier, String displayName, List<PartOfTerm> parts) {
        this.identifier = identifier;
        this.displayName = displayName;
		this.PartsOfTerm = parts;
	}
	public Term(String identifierAndName, List<PartOfTerm> parts) {
        this(identifierAndName, identifierAndName, parts);
    }

	/**
	 * Add a part of term to this Term Object
	 * @param p The Part Of Term to add
	 * @return True if it was added, false otherwise
	 */
	public boolean addPartOfTerm(PartOfTerm p){
		return PartsOfTerm.add(p);
	}

	/**
	 * Remove a part of Term from this Term Object
	 * @param p The Part Of Term to add
	 * @return True if it was removed, false otherwise
	 */
	public boolean removePartOfTerm(PartOfTerm p){
		return PartsOfTerm.remove(p);
	}

	/**
	 * Returns how many PartsOfTerm make up this term
	 * @return int number of PartsOfTerm this term has 
	 */
	public int getNumberOfPartOfTerms(){
		return PartsOfTerm.size();
	}
	public String getIdentifier() { return identifier; }

    public String getDisplayName() { return displayName; }

	/**
	 * Return the part of term within this term identified by the identifier.
	 * @param identifier  The identifier for the part of term we want to get
	 * @return PartOfTerm object with the same identifer
	 */
	public PartOfTerm getPartOfTerm(String identifier){
		for(PartOfTerm PoT:PartsOfTerm){
			if(PoT.getIdentifier() == identifier){
				return PoT;
			}
		}
		//otherwise return null
		return null;
	}

	public PartOfTerm getPartOfTerm(int i){
		return PartsOfTerm.get(i);
	}

	public List<String> getPartOfTerms(){
		List<String> out = new LinkedList<String>();
		for(PartOfTerm pot: PartsOfTerm){
			out.add(pot.getIdentifier());
		}
		return out;
	}

	public boolean equals(Object obj) {
        if (!(obj instanceof Term)) return false;
        if (obj == this) return true;

        return ((Term) obj).getIdentifier().equals(getIdentifier());
    }

    public int hashCode() {
        return getIdentifier().hashCode();
    }

	public int getNumber() {
		int out = 0;
		for(int i=0; i<Year.getInstance().getNumberOfTerms(); i++){
			if(Year.getInstance().getTerm(i).equals(this)){
				return i;
			}
		}
		return 0;
	}

	public int getPoTNumber(String PoT) {
		for(int i=0; i<PartsOfTerm.size();i++){
			if(PartsOfTerm.get(i).getIdentifier().equals(PoT)){
				return i;
			}
		}
		return 0;
	}
}
