package edu.rpi.scheduler.schedb.spec;

import java.util.List;
import java.util.LinkedList;

/**
 * A PartOfTerm is a part of a larger term (think semester).
 *
 * At WPI we generally refer to our PartOfTerms as Terms.
 *
 * todo: Consider if we need start and end dates in here.
 * User: Peter
 * Date: Sep 19, 2007
 * Time: 4:09:38 PM
 */
public class Year {

    private final String identifier;
    private final String displayName;
	private List<Term> Terms = new LinkedList<Term>();

	private Year(String identifierAndName) {
        this(identifierAndName, identifierAndName);
    }
    private Year(String identifier, String displayName) {
        this.identifier = identifier;
        this.displayName = displayName;
    }
	private Year(String identifier, String displayName, List<Term> terms) {
        this.identifier = identifier;
        this.displayName = displayName;
		this.Terms = terms;
	}
	private Year(String identifierAndName, List<Term> terms) {
        this(identifierAndName, identifierAndName, terms);
    }

	//Here we make this class a singleton so we always get the fully formed one back
	private static Year INSTANCE;
	public static Year getInstance(String identifierAndName){
		if(INSTANCE==null){
			return INSTANCE = new Year(identifierAndName);
		}else{
			return INSTANCE;
		}
	}
	public static Year getInstance(String identifier, String displayName){
		if(INSTANCE==null){
			return INSTANCE = new Year(identifier, displayName);
		}else{
			return INSTANCE;
		}
	}
	public static Year getInstance(String identifier, String displayName, List<Term> terms){
		if(INSTANCE==null){
			return INSTANCE = new Year(identifier, displayName, terms);
		}else{
			return INSTANCE;
		}
	}
	public static Year getInstance(String identifierAndName, List<Term> terms){
		if(INSTANCE==null){
			return INSTANCE = new Year(identifierAndName, terms);
		}else{
			return INSTANCE;
		}
	}

	public static Year getInstance(){
		return INSTANCE;
	}
	/**
	 * Add a Term to this Year Object
	 * @param t The Term to add
	 * @return True if it was added, false otherwise
	 */
	public boolean addTerm(Term t){
		return Terms.add(t);
	}

	/**
	 * Remove Term from this Year Object
	 * @param t The Term to add
	 * @return True if it was removed, false otherwise
	 */
	public boolean removeTerm(Term t){
		return Terms.remove(t);
	}

	/**
	 * Returns how many Terms make up this term
	 * @return int number of PartsOfTerm this term has
	 */
	public int getNumberOfTerms(){
		return Terms.size();
	}

	public int getNumberOfPartOfTerms(){
		int h = 0;
		for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {
			for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
				h++;
			}
		}
		return h;
	}

	public int getMaxNumberOfPartOfTerms(){
		int max = 0;
		int h = 0;
		for (int i = 0; i < getNumberOfTerms(); i++) {
			for (int j = 0; j < getTerm(i).getNumberOfPartOfTerms(); j++) {
				if(getTerm(i).getNumberOfPartOfTerms() > max){
					max = getTerm(i).getNumberOfPartOfTerms();
				}
			}
		}
		return max;
	}

	public String getIdentifier() { return identifier; }

    public String getDisplayName() { return displayName; }

	/**
	 * Return the term within this year identified by the identifier.
	 * @param identifier  The identifier for the Term we want to get
	 * @return Term object with the same identifer
	 */
	public Term getTerm(String identifier){
		for(Term t:Terms){
			if(t.getIdentifier().equals(identifier)){
				return t;
			}
		}
		//otherwise return null
		return null;
	}

	public Term getTerm(int i){
		return Terms.get(i);
	}

	/**
	 * Returns the term that contains a Part of Term with the given identifier.
	 * @param PoT String identifier that we want to find
	 * @return Term object that `ontains the given PoT. Null if not found.
	 */
	public Term getTermThatContainsPoT(String PoT){
		int h = 0;
		for (int i = 0; i < getNumberOfTerms(); i++) {
			if(getTerm(i).getPartOfTerms().contains(PoT)){
				return getTerm(i);
			}
		}
		return null;
	}

	public boolean equals(Object obj) {
        if (!(obj instanceof Year)) return false;
        if (obj == this) return true;

        return ((Year) obj).getIdentifier().equals(getIdentifier());
    }

    public int hashCode() {
        return getIdentifier().hashCode();
    }

}
