package edu.rpi.scheduler.ui.panels.courses;

import edu.rpi.scheduler.schedb.spec.Year;
import edu.rpi.scheduler.schedb.spec.Section;
import edu.rpi.scheduler.schedb.CourseDescriptor;
import edu.rpi.scheduler.schedb.SectionDescriptor;
import edu.rpi.scheduler.engine.SelectedCourse;
import edu.rpi.scheduler.ui.SchedulingSession;

import javax.swing.*;
import javax.swing.plaf.basic.BasicButtonUI;
import java.util.List;
import java.util.LinkedList;
import java.util.Iterator;
import java.util.Collection;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.*;
import java.awt.image.BufferedImage;

/**
 * This class extends JPanel to make a list of the terms we want or dont want this course
 */
public class TermNarrowingPanel extends JPanel {
    
	private ImageIcon emptyIcon = loadIcon("empty.png");
	private ImageIcon openIcon = loadIcon("open.png");
	private ImageIcon chosenIcon = loadIcon("chosen.png");
	private ImageIcon impossibleIcon = loadIcon("impossible.png");

	private List<List<JButton>> dots = new LinkedList<List<JButton>>();
	private SchedulingSession session = null;
	private ConflictDetector conflictDetector = null;

	public TermNarrowingPanel(CourseDescriptor cd, SchedulingSession s, ConflictDetector conflictDetector){
		this.session = s;
		this.conflictDetector = conflictDetector;
		this.setLayout(new GridLayout(1, Year.getInstance().getNumberOfPartOfTerms()));
		for(int i=0; i< Year.getInstance().getNumberOfTerms(); i++){
			List<JButton> internalList = new LinkedList<JButton>();
			for(int j=0; j<Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++){
				internalList.add(new JButton());
			}
			dots.add(internalList);
		}
		
		for(int i=0; i< Year.getInstance().getNumberOfTerms(); i++){
			List<JButton> internalList = new LinkedList<JButton>();
			for(int j=0; j<Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++){
				dots.get(i).get(j).setIcon(openIcon);
				dots.get(i).get(j).setUI(new BasicButtonUI());
				//dots.get(i).get(j).setBorder(null);
				dots.get(i).get(j).setBorderPainted(false);
				dots.get(i).get(j).setFocusPainted(false);
				dots.get(i).get(j).setBackground(Color.WHITE);
				dots.get(i).get(j).setForeground(getBackground());
				dots.get(i).get(j).setVerticalAlignment(SwingConstants.TOP);
				//dots.get(i).get(j).addActionListener(new ButtonListener(Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier(), cd));
				dots.get(i).get(j).setAction(new ButtonPress(Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier(), cd));
				this.add(dots.get(i).get(j));
			}
		}
	}

	
	
	private ImageIcon loadIcon(String name) {

		BufferedImage bi = new BufferedImage(11, 11, BufferedImage.TYPE_INT_ARGB);
		bi.getGraphics().drawImage((new ImageIcon(TermNarrowingPanel.class.getResource(name))).getImage()
				, 0, 0, 11, 11, null);
		return new ImageIcon(bi);
	}

	public List<List<JButton>> getButtons(){
		return dots;
	}

	/**
	 * This function sets the icons that we should use on our buttons for the given
	 * course.
	 *
	 * This is VERY similar to the text coloring in XMLConfiguredUIPlugin.
	 *
	 * @param cd the CourseDescriptor that we are building buttons for
	 * @param selectedCourses What courses we have already selected
	 * @param conflictDetector that we should use.
	 */
	public void setButtonIcons(CourseDescriptor cd, SelectedCoursesList selectedCourses,
            ConflictDetector conflictDetector) {

		//Let's figure out when this course is offered
		List<String> offered = cd.getActualCourse().getPartOfTermsOffered();

		//for making |s between PoTs
		int numberOfPoT = Year.getInstance().getNumberOfPartOfTerms();
		int k = 0;

		//Loop over each PoT
		for(int i=0; i<Year.getInstance().getNumberOfTerms(); i++){
			for(int j=0; j<Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++){

				boolean wouldFit = conflictDetector.wouldFitAnyScheduleInPoT(cd,
						Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier());
				//let's figure out if our course is offered this PoT
				boolean isOffered = offered.contains(Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier());

				//Now let's figure out if we conflict with anything besides ourself
				/*Old method
				boolean secondaryConflict = false;
				//get all the conflicts with this course
				for(Iterator<SelectedCourse> it = conflictDetector.getSelectedConflicts(cd).iterator(); it.hasNext();) {
                	SelectedCourse course = it.next();
					//if we're not conflicting withourself, we must be conflicting with another course
					if(!course.getCourse().equals(cd)){
						secondaryConflict = true;
					}
				} */

				if(!isOffered){
					//gray if it's not offered
					dots.get(i).get(j).setIcon(emptyIcon);
				}else if(!wouldFit){
					//red if it is offered but it is blocked
					dots.get(i).get(j).setIcon(impossibleIcon);
				}else if(session.getUIPlugin().isRemoved(cd, i, j)){
					//open if it is offered but it is blocked
					dots.get(i).get(j).setIcon(openIcon);
				}else{
					//otherwise green
					dots.get(i).get(j).setIcon(chosenIcon);
				}

				k++;
			}
		}
		this.repaint();
	}


	public class ButtonPress extends AbstractAction{
		private String PoT;
		private CourseDescriptor cd;
		public ButtonPress(String PoT, CourseDescriptor cd){
			this.PoT = PoT;
			this.cd = cd;
		}

		public void actionPerformed(ActionEvent actionEvent) {
			
			//first let's find our term
			for(int i=0; i< Year.getInstance().getNumberOfTerms(); i++){
				for(int j=0; j<Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++){
					if(Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier().equals(PoT)){

						if(conflictDetector.wouldFitAnyScheduleInPoT(cd, Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier())){
							if(session.getUIPlugin().isRemoved(cd, i, j)){
								//if we are here we have already blocked this term of this course
								session.getEngine().UnblockCourseByTerm(cd, PoT);
								conflictDetector.UnblockCourseByTerm(cd,PoT);
								//updateDotIsPressed(i, j, new Boolean(false));
							}else{
								//if we are here we need to block this term of this course
								session.getEngine().BlockCourseByTerm(cd, PoT);
								conflictDetector.BlockCourseByTerm(cd,PoT);
								//updateDotIsPressed(i, j, new Boolean(true));
							}
						}
					}
				}
			}
		}
	}
}
