package edu.rpi.scheduler.ui.panels.listing;

import edu.rpi.scheduler.schedb.spec.Year;
import edu.rpi.scheduler.schedb.spec.Schedule;
import edu.rpi.scheduler.schedb.UniqueSection;
import edu.rpi.scheduler.schedb.CourseDescriptor;
import edu.rpi.scheduler.schedb.SectionDescriptor;
import edu.rpi.scheduler.ui.panels.DefaultSubpanel;
import edu.rpi.scheduler.ui.SchedulingSession;
import edu.rpi.scheduler.ui.UITools;
import edu.rpi.scheduler.ui.WindowType;

import javax.swing.*;
import javax.swing.border.Border;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import java.util.*;
import java.util.List;
import java.awt.*;

/**
 * This panel is the final panel.  It shows the course and section names and IDs for the
 * schedule that was selected.  It may also eventually include text saying how to register for classes.
 */
public class listingPanel extends DefaultSubpanel {
	private JComponent Listing;
	private JTextPane Instructions;
	private JPanel mainPanel;
	private List<List<jlistWrapper>> jlists = new LinkedList<List<jlistWrapper>>();
	private Schedule schedule;
	private SchedulingSession mySession;

	/**
	 * Empty Constructor
	 */
	public listingPanel(){
	}

	/**
	 * This function gets called when we enter this panel.  The ScheduleWindow calls this for us.
	 * Basicly, we make sure the currently selected schedule is being displayed.
	 */
	public void entering(){
		setSchedule(getSession().getSelectedSchdule());
		updateInstructions();
	}

	{

		/**
		 * This block of code initializes the panel itself
		 */
		//Make sure we populate this with the correct number of sub components
		for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {
			List<jlistWrapper> internalList = new LinkedList();
			for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
				internalList.add(new jlistWrapper(Year.getInstance().getTerm(i).getIdentifier(), Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier()));
			}
			jlists.add(internalList);
		}
		
		mainPanel = new JPanel();
		setLayout(new GridLayout(1,1));
		add(mainPanel);

		mainPanel.setLayout(new GridBagLayout());

		//Initialize our panels
		Listings();
		Instructions();

		//Display our Instructions
		GridBagConstraints c = new GridBagConstraints();
		c.fill = GridBagConstraints.HORIZONTAL;
		c.gridx = 0;
		c.gridy = 0;
		c.anchor = GridBagConstraints.WEST;
		c.weightx = 0.5;
		c.weighty = 0;
		mainPanel.add(Instructions, c);

		//at least display our final selection of courses
		c.fill = GridBagConstraints.BOTH;
		c.gridx = 0;
		c.gridy = 1;
		c.anchor = GridBagConstraints.CENTER;
		c.weightx = 0.5;
		c.weighty = 1;
		mainPanel.add(Listing, c);
	}




	/**
	 * This function initializes the Listings Component by setting all the jlistWrapper's
	 * as visible and adding them to the Listing panel.
	 * @return Listing Panel with all associated sub panels
	 */
	private JComponent Listings(){
        Listing = new JPanel();
		Listing.setLayout(new GridBagLayout());

		for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {

			for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
				jlistWrapper localjlw = jlists.get(i).get(j);
				localjlw.setVisible(true);

				GridBagConstraints c = new GridBagConstraints();
				c.fill = GridBagConstraints.BOTH;
				c.gridx = i;
				c.gridy = j;
				c.anchor = GridBagConstraints.CENTER;
				c.weightx = 0.5;
				c.weighty = 0.5;

				Listing.add(localjlw, c);
			}
		}
		Listing.setAutoscrolls(true);
		Listing.setVisible(true);

		return Listing;

	}

	/**
	 * This function initializes the Instructions Component
	 * @return JPanel that has our Instructions text.
	 */
	private JComponent Instructions(){
		//Setup the main instructions
		Instructions = new JTextPane();
		Instructions.setContentType("text/html");
		Instructions.setOpaque(false);
		if(getSession()!=null){
			Instructions.setText("<html style=\"font-size:12;\">"+getSession().getUIPlugin().getRegInstructionText());
		}else{
			Instructions.setText("");
		}
		Instructions.setEditable(false);
		Instructions.setAutoscrolls(true);
		Instructions.setVisible(true);

		return Instructions;

	}

	/**
	 * This updates the text shown in the instructions field.  We have to do this after we have a
	 * valid session, which we do not have upon initialization, so we call this later.
	 */
	private void updateInstructions(){
		Instructions.setText("<html style=\"font-size:12;\">"+getSession().getUIPlugin().getRegInstructionText());
	}
	
	public JComponent $$$getRootComponent$$$() {
		return mainPanel;
	}

	/**
	 * This function sets the Schedule that we are displaying.  It gets called when we
	 * enter this panel.
	 * @param s Schedule that we want to show
	 */
	public void setSchedule(Schedule s){
		for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {

			for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
				Collection<UniqueSection> uss = s.getSections(Year.getInstance().getTerm(i).getIdentifier(), Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier());
				jlists.get(i).get(j).setSchedule(uss);

			}
		}
	}

	public String getPanelTitle() {
		return "Register For These Classes";
	}
}
