package edu.rpi.scheduler.ui.widgets;

import edu.rpi.scheduler.schedb.YearMask;
import edu.rpi.scheduler.schedb.TermMask;
import edu.rpi.scheduler.schedb.WeekMask;
import edu.rpi.scheduler.schedb.spec.Year;
import edu.rpi.scheduler.ui.SchedulingSession;
import edu.rpi.scheduler.ui.TimeGridType;

import javax.swing.*;
import javax.swing.text.html.*;
import java.text.NumberFormat;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import java.util.*;
import java.util.List;
import java.awt.*;

/**
 * A component allowing the user to block out times interactively on a grid.
 *
 * This Grid represents an entire year!  It has a bunch of TimeSelector's that each represent
 *  a single part of Term.
 *
 * Most of these methods just push commands down to it's children or vice versa
 */
public class YearTimeSelector extends JPanel {
    public static final String PROP_TIMEMASK = "timeMask";

    private List<List<TimeSelector>> myTimes = new LinkedList<List<TimeSelector>>();
    private List<List<JLabel>> myTimesLabel = new LinkedList<List<JLabel>>();
    static YearTimeSelector INSTANCE;


    public static YearTimeSelector getInstance(){
        if(INSTANCE == null){
            INSTANCE = new YearTimeSelector();
        }
        return INSTANCE;
    }

    public static YearTimeSelector getInstance(SchedulingSession session){
        if(INSTANCE == null){
            INSTANCE = new YearTimeSelector(session);
        }
        INSTANCE.populatemyTimes(session);
        return INSTANCE;
    }


    private boolean isTimeBlockOn(String term, String PoT, int day, int block) {

        //Loop and find what number our term is
        int i=0;
        while(term != Year.getInstance().getTerm(i).getIdentifier()){
            i++;
        }
        //Loop and find what number our part of term is
        int j=0;
        while(PoT != Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier()){
            j++;
        }

        return myTimes.get(i).get(j).isTimeBlockOn(day, block);
    }

    private final NumberFormat format = NumberFormat.getNumberInstance();

    {
        format.setMinimumIntegerDigits(2);
    }

    private YearMask<?> timeMask = null;

    private List<List<PropertyChangeSupport>> pcs = new LinkedList<List<PropertyChangeSupport>>();

    private YearTimeSelector() {
        this(null);
    }

    /**
     * Construct a YearTimeSelector containing child TimeSelectors for each Term and Part Of Term
     * @param session the session we are working with
     */
    private YearTimeSelector(SchedulingSession session) {
        populatemyTimes(session);
        int i=0;
        for(List<TimeSelector> lt: myTimes){
            List<PropertyChangeSupport> localPCS = new LinkedList<PropertyChangeSupport>();
            int j=0;
            for(TimeSelector lsg: lt){
                localPCS.add(new PropertyChangeSupport(myTimes.get(i).get(j)));//org: this);
                j++;
            }
            pcs.add(localPCS);
            i++;
        }
        i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;
            for(TimeSelector lsg: lt){
                myTimes.get(i).get(j).setSession(session);
                j++;
            }
            i++;
        }
        /*for(List<TimeSelector> lt: myTimes){
              for(TimeSelector l: lt){
                  l.setSession(session);
              }
          }*/
        //CombinedDisplayYearTimeSelectorOverlay();
    }

	/**
	 * This function loops through and populates our list of myTimes
	 * with TimeSelectors, one for each PoT.
	 * @param session the SchedulingSession that each of the children should be associated with 
	 */
	private void populatemyTimes(SchedulingSession session){
        for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {
            List<TimeSelector> internalList = new LinkedList();
            for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
                internalList.add(new TimeSelector(session));
            }
            myTimes.add(internalList);
        }
        populatemyTimesLabel();
    }
	/**
	 * This function loops through and populates our labels with the right PoT info 
	 * one for each PoT. 
	 */
    private void populatemyTimesLabel(){
        for (int i = 0; i < Year.getInstance().getNumberOfTerms(); i++) {
            List<JLabel> internalJLabelList = new LinkedList();
            for (int j = 0; j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms(); j++) {
                internalJLabelList.add(new JLabel(Year.getInstance().getTerm(i).getPartOfTerm(j).getIdentifier()));
            }
            myTimesLabel.add(internalJLabelList);
        }
    }

    public JComponent CombinedDisplayYearTimeSelectorOverlay()
    {
        setLayout(new BorderLayout());
        JPanel p = new JPanel();
        OverlayLayout overlay = new OverlayLayout(p);
        p.setLayout(overlay);
		
		p.add(DisplayYearTimeSelector(), 0);
		p.add(DisplayYearTimeSelectorOverylay(), 1);

        add(p, BorderLayout.CENTER);

        return p;
    }

    public JPanel DisplayYearTimeSelector(){
        JPanel YTS = new JPanel();
        YTS.setLayout(new GridLayout(0,Year.getInstance().getMaxNumberOfPartOfTerms()));

        List<List<TimeSelector>> tgList = new LinkedList<List<TimeSelector>>();
        int i=0;

        for(java.util.List<TimeSelector> lt: myTimes){
            int j=0;
            List<TimeSelector> localList = new LinkedList<TimeSelector>();
            for(TimeSelector lsg: lt){
                localList.add(myTimes.get(i).get(j));
                j++;
            }
            tgList.add(localList);
            i++;
        }
        i=0;
        for(List<TimeSelector> lt:tgList){
            int j=0;
            for(TimeSelector lsg: lt){
                //myTimesLabel.get(i).get(j).setVisible(true);
                //YTS.add(myTimesLabel.get(i).get(j));
                tgList.get(i).get(j).setVisible(true);
                YTS.add(tgList.get(i).get(j));
                j++;
            }
            i++;
        }
        YTS.setVisible(true);

	
        YTS.setOpaque(false);
        return YTS;
    }
    public static int PLAIN;
    public static int CENTER;
    public JPanel DisplayYearTimeSelectorOverylay(){

        JPanel YTSO = new JPanel();
        YTSO.setLayout(new GridLayout(0,Year.getInstance().getMaxNumberOfPartOfTerms()));

        //YTSO.setSize(YTSO.getMaximumSize());
        YTSO.setVisible(false);
        YTSO.setOpaque(true);
        int i=0;
        while(i < Year.getInstance().getNumberOfTerms()){
            int j=0;
            while(j < Year.getInstance().getTerm(i).getNumberOfPartOfTerms()){
                myTimesLabel.get(i).get(j).setVisible(true);
                myTimesLabel.get(i).get(j).setFont(new Font("Arial",PLAIN,40));
                myTimesLabel.get(i).get(j).setHorizontalAlignment(CENTER);
                myTimesLabel.get(i).get(j).setOpaque(false);
                YTSO.add(myTimesLabel.get(i).get(j));

				j++;
			}
			i++;
		}
         YTSO.setVisible(true);
         YTSO.setBackground(Color.WHITE);
         return YTSO;
     }

	/**
	 * This sets the SchedulingSession that we are part of.  This function
	 * essentially just pushes the passed value to each of our children TimeSelectors
	 * @param session SchedulingSession that we want to be part of
	 */
	public void setSession(SchedulingSession session) {
        int i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;
            for(TimeSelector lsg: lt){
                myTimes.get(i).get(j).setSession(session);
                j++;
            }
            i++;
        }

        /*for(List<TimeSelector> lt: myTimes){
			for(TimeSelector l: lt){
				l.setSession(session);
			}
		}*/

        if (session != null) {
            clearTimeMask();
        } else {
            timeMask = null;
        }
    }

	/**
	 * This removes the mask from this YearTimeSelector by pushing
	 * the request down to each of our children TimeSelectors
	 */
	public void clearTimeMask() {
        int i=0;

        for(List<TimeSelector> lt: myTimes){
            int j=0;
            for(TimeSelector lsg: lt){
                myTimes.get(i).get(j).clearTimeMask();
                j++;
            }
            i++;
        }
    }


    /**
     * Sets the blocked time mask to be displayed and edited by the user.
	 * This essentially pushes down the appropriate part of this data to
	 * each of our child TimeSelectors
     * @param mask the blocked time mask to be edited
     */
    public void setTimeMask(YearMask<?> mask) {
        this.timeMask = mask;


        int i=0;
		int j=0;

        for(List<TimeSelector> lt: myTimes){
            j=0;
            for(TimeSelector lsg: lt){
				myTimes.get(i).get(j).setTimeMask(mask.getTerm(i).getWeekMask(j));
				myTimes.get(i).get(j).repaint();
                j++;
            }
            i++;
        }

        /*for(List<TimeSelector> lt: myTimes){
			for(TimeSelector l: lt){
				l.repaint();*/
    }

    /**
     * Returns the current time mask, which may or may not have been edited by
     * the user.
     * @return the time mask being displayed and edited
     */
    public YearMask<?> getYearTimeMask() {

        YearMask<?> totalYearMask = YearMask.newMask(TermMask.class);

        int i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;
            TermMask<?> localTermMask = TermMask.newMask(WeekMask.class, Year.getInstance().getTerm(i).getIdentifier());
            for(TimeSelector lsg: lt){
                localTermMask.add(j, myTimes.get(i).get(j).getTimeMask());
                j++;
            }
            totalYearMask.add(i, localTermMask);
            i++;
        }
        timeMask = totalYearMask;
        return timeMask;
    }

    /**
     * This function returns true if at least one of the child TimeSelectors is not null
     * @return True if one child is not null.  False if all children are null
     */
    public boolean IsAtLeastOneChildNotNull() {
        int i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;

            for(TimeSelector lsg: lt){
                if(myTimes.get(i).get(j)!=null) return true;
                j++;
            }
            i++;
        }
        return false;
    }

    protected TimeGridType getTimeGridType() {
        return TimeGridType.TIME_SELECTOR;
    }

    public void addTimeMaskChangeListener(PropertyChangeListener listener) {
        int i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;
            for(TimeSelector lsg: lt){
                myTimes.get(i).get(j).addTimeMaskChangeListener(listener);
                j++;
            }
            i++;
        }

    }

    public void removeTimeMaskChangeListener(PropertyChangeListener listener) {
        int i=0;
        for(List<TimeSelector> lt: myTimes){
            int j=0;
            for(TimeSelector lsg: lt){
                myTimes.get(i).get(j).removeTimeMaskChangeListener(listener);
                j++;
            }
            i++;
        }
    }

}
